[U-Boot] [PATCH 06/30] dm: sound: samsung: Rename i2stx_info to samsung_i2s_priv

Simon Glass sjg at chromium.org
Mon Dec 3 11:37:22 UTC 2018


This struct is only used by the Samsung I2C driver and should move into
that driver. For now, rename it so it is clear that is driver-private
info.

Signed-off-by: Simon Glass <sjg at chromium.org>
---

 drivers/sound/samsung-i2s.c |  6 +++---
 drivers/sound/sound-i2s.c   | 10 +++++-----
 include/i2s.h               |  8 ++++----
 3 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/drivers/sound/samsung-i2s.c b/drivers/sound/samsung-i2s.c
index 8f5cd191a2b..7f4388137a5 100644
--- a/drivers/sound/samsung-i2s.c
+++ b/drivers/sound/samsung-i2s.c
@@ -255,8 +255,8 @@ static int i2s_set_samplesize(struct i2s_reg *i2s_reg, unsigned int blc)
 	return 0;
 }
 
-int i2s_transfer_tx_data(struct i2stx_info *pi2s_tx, unsigned int *data,
-				unsigned long data_size)
+int i2s_transfer_tx_data(struct samsung_i2s_priv *pi2s_tx, unsigned int *data,
+			 unsigned long data_size)
 {
 	int i;
 	int start;
@@ -293,7 +293,7 @@ int i2s_transfer_tx_data(struct i2stx_info *pi2s_tx, unsigned int *data,
 	return 0;
 }
 
-int i2s_tx_init(struct i2stx_info *pi2s_tx)
+int i2s_tx_init(struct samsung_i2s_priv *pi2s_tx)
 {
 	int ret;
 	struct i2s_reg *i2s_reg =
diff --git a/include/i2s.h b/include/i2s.h
index e6d45ec26d7..800473abd9c 100644
--- a/include/i2s.h
+++ b/include/i2s.h
@@ -76,7 +76,7 @@ struct i2s_reg {
 };
 
 /* This structure stores the i2s related information */
-struct i2stx_info {
+struct samsung_i2s_priv {
 	unsigned int rfs;		/* LR clock frame size */
 	unsigned int bfs;		/* Bit slock frame size */
 	unsigned int audio_pll_clk;	/* Audio pll frequency in Hz */
@@ -96,8 +96,8 @@ struct i2stx_info {
  *
  * @return		int value 0 for success, -1 in case of error
  */
-int i2s_transfer_tx_data(struct i2stx_info *pi2s_tx, unsigned *data,
-				unsigned long data_size);
+int i2s_transfer_tx_data(struct samsung_i2s_priv *pi2s_tx, uint *data,
+			 unsigned long data_size);
 
 /*
  * Initialise i2s transmiter
@@ -106,6 +106,6 @@ int i2s_transfer_tx_data(struct i2stx_info *pi2s_tx, unsigned *data,
  *
  * @return		int value 0 for success, -1 in case of error
  */
-int i2s_tx_init(struct i2stx_info *pi2s_tx);
+int i2s_tx_init(struct samsung_i2s_priv *pi2s_tx);
 
 #endif /* __I2S_H__ */
diff --git a/drivers/sound/sound-i2s.c b/drivers/sound/sound-i2s.c
index f0f0b79bc52..106842a23db 100644
--- a/drivers/sound/sound-i2s.c
+++ b/drivers/sound/sound-i2s.c
@@ -20,15 +20,15 @@
 #define SOUND_400_HZ 400
 #define SOUND_BITS_IN_BYTE 8
 
-static struct i2stx_info g_i2stx_pri;
+static struct samsung_i2s_priv g_i2stx_pri;
 
 /*
  * get_sound_i2s_values gets values for i2s parameters
  *
  * @param i2stx_info	i2s transmitter transfer param structure
  * @param blob		FDT blob if enabled else NULL
  */
-static int get_sound_i2s_values(struct i2stx_info *i2s, const void *blob)
+static int get_sound_i2s_values(struct samsung_i2s_priv *i2s, const void *blob)
 {
 	int node;
 	int error = 0;
@@ -97,7 +97,7 @@ static int get_sound_i2s_values(struct i2stx_info *i2s, const void *blob)
  * @param pi2s_tx	i2s parameters required by codec
  * @return              int value, 0 for success
  */
-static int codec_init(const void *blob, struct i2stx_info *pi2s_tx)
+static int codec_init(const void *blob, struct samsung_i2s_priv *pi2s_tx)
 {
 	int ret;
 	const char *codectype;
@@ -145,7 +145,7 @@ static int codec_init(const void *blob, struct i2stx_info *pi2s_tx)
 int sound_init(const void *blob)
 {
 	int ret;
-	struct i2stx_info *pi2s_tx = &g_i2stx_pri;
+	struct samsung_i2s_priv *pi2s_tx = &g_i2stx_pri;
 
 	/* Get the I2S Values */
 	if (get_sound_i2s_values(pi2s_tx, blob) < 0) {
@@ -20,15 +20,15 @@
  * get_sound_i2s_values gets values for i2s parameters
  *
- * @param i2stx_info	i2s transmitter transfer param structure
+ * @param samsung_i2s_priv	i2s transmitter transfer param structure
  * @param blob		FDT blob if enabled else NULL
  */
-- 
2.20.0.rc1.387.gf8505762e3-goog



More information about the U-Boot mailing list